@@ -24,11 +24,11 @@ class PlayerTasks(MixinMeta, metaclass=CompositeMetaClass):
         pause_times: Dict = {}
         while True:
             async for p in AsyncIter(lavalink.all_players()):
-                server = p.channel.guild
+                server = p.guild
                 if await self.bot.cog_disabled_in_guild(self, server):
                     continue
 
-                if [self.bot.user] == p.channel.members:
+                if p.channel.members and all(m.bot for m in p.channel.members):
                     stop_times.setdefault(server.id, time.time())
                     pause_times.setdefault(server.id, time.time())
                 else:
@@ -37,11 +37,7 @@ class PlayerTasks(MixinMeta, metaclass=CompositeMetaClass):
                         try:
                             await p.pause(False)
                         except Exception as err:
-                            debug_exc_log(
-                                log,
-                                err,
-                                f"Exception raised in Audio's unpausing player for {server.id}.",
-                            )
+                            debug_exc_log(log, err, "Exception raised in Audio's unpausing %r.", p)
                     pause_times.pop(server.id, None)
             servers = stop_times.copy()
             servers.update(pause_times)
@@ -61,7 +57,7 @@ class PlayerTasks(MixinMeta, metaclass=CompositeMetaClass):
                         ).currently_auto_playing_in.set([])
                     except Exception as err:
                         debug_exc_log(
-                            log, err, f"Exception raised in Audio's emptydc_timer for {sid}."
+                            log, err, "Exception raised in Audio's emptydc_timer for %s.", sid
                         )
 
                 elif sid in stop_times and await self.config.guild(server_obj).emptydc_enabled():
@@ -81,7 +77,7 @@ class PlayerTasks(MixinMeta, metaclass=CompositeMetaClass):
                             if "No such player for that guild" in str(err):
                                 stop_times.pop(sid, None)
                             debug_exc_log(
-                                log, err, f"Exception raised in Audio's emptydc_timer for {sid}."
+                                log, err, "Exception raised in Audio's emptydc_timer for %s.", sid
                             )
                 elif (
                     sid in pause_times and await self.config.guild(server_obj).emptypause_enabled()
@@ -94,6 +90,6 @@ class PlayerTasks(MixinMeta, metaclass=CompositeMetaClass):
                             if "No such player for that guild" in str(err):
                                 pause_times.pop(sid, None)
                             debug_exc_log(
-                                log, err, f"Exception raised in Audio's pausing for {sid}."
+                                log, err, "Exception raised in Audio's pausing for %s.", sid
                             )
             await asyncio.sleep(5)
