@@ -61,6 +61,7 @@ class TriviaSession:
          - ``bot_plays`` (`bool`)
          - ``allow_override`` (`bool`)
          - ``payout_multiplier`` (`float`)
+         - ``use_spoilers`` (`bool`)
     scores : `collections.Counter`
         A counter with the players as keys, and their scores as values. The
         players are of type `discord.Member`.
@@ -114,6 +115,8 @@ class TriviaSession:
             fut.result()
         except asyncio.CancelledError:
             pass
+        except (discord.NotFound, discord.Forbidden):
+            self.stop()
         except Exception as exc:
             LOG.error("A trivia session has encountered an error.\n", exc_info=exc)
             asyncio.create_task(
