@@ -21,14 +21,17 @@ from .commands import (
 from .context import Context as Context, GuildContext as GuildContext, DMContext as DMContext
 from .converter import (
     DictConverter as DictConverter,
-    GuildConverter as GuildConverter,
+    RelativedeltaConverter as RelativedeltaConverter,
     TimedeltaConverter as TimedeltaConverter,
     get_dict_converter as get_dict_converter,
     get_timedelta_converter as get_timedelta_converter,
+    parse_relativedelta as parse_relativedelta,
     parse_timedelta as parse_timedelta,
     NoParseOptional as NoParseOptional,
     UserInputOptional as UserInputOptional,
     Literal as Literal,
+    CogConverter as CogConverter,
+    CommandConverter as CommandConverter,
 )
 from .errors import (
     ConversionFailure as ConversionFailure,
@@ -84,6 +87,7 @@ from ._dpy_reimplements import (
 from discord.ext.commands import (
     BadArgument as BadArgument,
     EmojiConverter as EmojiConverter,
+    GuildConverter as GuildConverter,
     InvalidEndOfQuotedStringError as InvalidEndOfQuotedStringError,
     MemberConverter as MemberConverter,
     BotMissingRole as BotMissingRole,
@@ -103,6 +107,7 @@ from discord.ext.commands import (
     ExtensionError as ExtensionError,
     Cooldown as Cooldown,
     CheckFailure as CheckFailure,
+    PartialMessageConverter as PartialMessageConverter,
     MessageConverter as MessageConverter,
     MissingPermissions as MissingPermissions,
     BadUnionArgument as BadUnionArgument,
@@ -130,6 +135,8 @@ from discord.ext.commands import (
     ColourConverter as ColourConverter,
     ColorConverter as ColorConverter,
     VoiceChannelConverter as VoiceChannelConverter,
+    StageChannelConverter as StageChannelConverter,
+    StoreChannelConverter as StoreChannelConverter,
     NSFWChannelRequired as NSFWChannelRequired,
     IDConverter as IDConverter,
     MissingRequiredArgument as MissingRequiredArgument,
@@ -147,6 +154,7 @@ from discord.ext.commands import (
     MaxConcurrencyReached as MaxConcurrencyReached,
     bot_has_guild_permissions as bot_has_guild_permissions,
     CommandRegistrationError as CommandRegistrationError,
+    GuildNotFound as GuildNotFound,
     MessageNotFound as MessageNotFound,
     MemberNotFound as MemberNotFound,
     UserNotFound as UserNotFound,
