@@ -78,6 +78,7 @@ class HelpSettings:
     tagline: str = ""
     delete_delay: int = 0
     use_tick: bool = False
+    react_timeout: int = 30
 
     # Contrib Note: This is intentional to not accept the bot object
     # There are plans to allow guild and user specific help settings
@@ -131,6 +132,7 @@ class HelpSettings:
             "\nHelp shows unusable commands when asked directly: {verify_exists}"
             "\nDelete delay: {delete_delay}"
             "\nReact with a checkmark when help is sent via DM: {use_tick}"
+            "\nReaction timeout (only used if menus are used): {react_timeout} seconds"
             "{tagline_info}"
         ).format_map(data)
 
@@ -356,7 +358,7 @@ class RedHelpFormatter(HelpFormatterABC):
             grp = cast(commands.Group, command)
             subcommands = await self.get_group_help_mapping(ctx, grp, help_settings=help_settings)
 
-        if await ctx.embed_requested():
+        if await self.embed_requested(ctx):
             emb = {"embed": {"title": "", "description": ""}, "footer": {"text": ""}, "fields": []}
 
             if description:
@@ -537,7 +539,7 @@ class RedHelpFormatter(HelpFormatterABC):
         description = obj.format_help_for_context(ctx)
         tagline = (help_settings.tagline) or self.get_default_tagline(ctx)
 
-        if await ctx.embed_requested():
+        if await self.embed_requested(ctx):
             emb = {"embed": {"title": "", "description": ""}, "footer": {"text": ""}, "fields": []}
 
             emb["footer"]["text"] = tagline
@@ -604,7 +606,7 @@ class RedHelpFormatter(HelpFormatterABC):
         description = ctx.bot.description or ""
         tagline = (help_settings.tagline) or self.get_default_tagline(ctx)
 
-        if await ctx.embed_requested():
+        if await self.embed_requested(ctx):
 
             emb = {"embed": {"title": "", "description": ""}, "footer": {"text": ""}, "fields": []}
 
@@ -703,6 +705,11 @@ class RedHelpFormatter(HelpFormatterABC):
             else:
                 yield obj
 
+    async def embed_requested(self, ctx: Context) -> bool:
+        return await ctx.bot.embed_requested(
+            channel=ctx.channel, user=ctx.author, command=red_help, check_permissions=True
+        )
+
     async def command_not_found(self, ctx, help_for, help_settings: HelpSettings):
         """
         Sends an error, fuzzy help, or stays quiet based on settings
@@ -715,7 +722,7 @@ class RedHelpFormatter(HelpFormatterABC):
             ),
             min_score=75,
         )
-        use_embeds = await ctx.embed_requested()
+        use_embeds = await self.embed_requested(ctx)
         if fuzzy_commands:
             ret = await format_fuzzy_results(ctx, fuzzy_commands, embed=use_embeds)
             if use_embeds:
@@ -749,7 +756,7 @@ class RedHelpFormatter(HelpFormatterABC):
         ret = _("Command *{command_name}* has no subcommand named *{not_found}*.").format(
             command_name=command.qualified_name, not_found=not_found[0]
         )
-        if await ctx.embed_requested():
+        if await self.embed_requested(ctx):
             ret = discord.Embed(color=(await ctx.embed_color()), description=ret)
             ret.set_author(
                 name=_("{ctx.me.display_name} Help Menu").format(ctx=ctx),
@@ -857,7 +864,9 @@ class RedHelpFormatter(HelpFormatterABC):
             m = await (ctx.send(embed=pages[0]) if embed else ctx.send(pages[0]))
             c = menus.DEFAULT_CONTROLS if len(pages) > 1 else {"\N{CROSS MARK}": menus.close_menu}
             # Allow other things to happen during menu timeout/interaction.
-            asyncio.create_task(menus.menu(ctx, pages, c, message=m))
+            asyncio.create_task(
+                menus.menu(ctx, pages, c, message=m, timeout=help_settings.react_timeout)
+            )
             # menu needs reactions added manually since we fed it a message
             menus.start_adding_reactions(m, c.keys())
 
