@@ -99,7 +99,7 @@ async def _init(bot: Red):
 
     async def on_member_ban(guild: discord.Guild, member: discord.Member):
 
-        if not guild.me.guild_permissions.view_audit_log:
+        if guild.unavailable or not guild.me.guild_permissions.view_audit_log:
             return
 
         try:
@@ -136,7 +136,7 @@ async def _init(bot: Red):
             await asyncio.sleep(300)
 
     async def on_member_unban(guild: discord.Guild, user: discord.User):
-        if not guild.me.guild_permissions.view_audit_log:
+        if guild.unavailable or not guild.me.guild_permissions.view_audit_log:
             return
 
         try:
